# Usage: perl createB.pl -method Base -cohort 1 -target 0 -coverp 10 -clength 5 -noisep 0 -lcount 50

use strict;
use warnings;
use Carp;

my @targets=('N', 'S'); 
my @cohorts=('O', 'Y');

#Process input and create files
my %args = @ARGV;
my $method  = $args{-method} || 
    confess "Input a method as: -method method[DP|Gen|Base]";
my $t =  $args{-target}; 
confess "Input the target as: -target target" if !defined $t;
my $c =  $args{-cohort};
confess "Input the cohort as: -cohort cohort" if !defined $c;
my $coverp =  $args{-coverp} || 
    confess "Input the cover percentage as: -coverp coverp";
my $clauseLength = $args{-clength} || 
    confess "Input the max clause length as: -clength clength";
my $noisep =  $args{-noisep} || 0;
my $lcount = $args{-lcount} ||
    confess "Input the line count: -lcount lcount";

#create aleph parameters
my $data = "../data/";
my $results = "../results/";
my $output = "instructions.b";
my $input = $method.$output;
my $noise = int($lcount * $noisep / 100);
my $cover = int($lcount * $coverp / 100);
my $fileName = "$method\_$cohorts[$c]$targets[$t]\_$coverp\_$noisep";

open(INPUT, $input) ||
    confess "couldn't open ", $input, ": $!. Stopped"; 
open(OUTPUT, '>', "instructions.b") ||
    confess "couldn't open ", $output, ": $!. Stopped";

#write aleph .b file
while (my $line = <INPUT>){
    $line =~ s/(set\(clauselength,)(\s*\d*)/$1$clauseLength/;
    $line =~ s/(set\((minpos|m),)(\s*\d*)/$1$cover/;
    $line =~ s/(set\((noise),)(\s*\d*)/$1$noise/;

    $line =~ s/(set\(recordfile,\s*)(.*)(\).)/$1'$results$fileName.trace'$3/;
    $line =~ s/(set\(rulefile,\s*)(.*)(\).)/$1'$results$fileName.hyp'$3/;

    #ignored by base anyways
    $line =~ s/(alt_train_pos:\s*)(.*)(\].)/$1'$data$cohorts[($c+1)%2]$targets[$t].fn'$3/;
    $line =~ s/(alt_train_neg:\s*)(.*)(\].)/$1'$data$cohorts[($c+1)%2]$targets[($t+1)%2].fn'$3/;

    if ($method eq "Base"){
	$line =~ s/(set\(train_pos,\s*)(.*)(\).)/$1'$data$targets[$t].fn'$3/;
	$line =~ s/(set\(train_neg,\s*)(.*)(\).)/$1'$data$targets[($t+1)%2].fn'$3/;
	$line =~ s/(consult\()(.*)(\).)/$1${data}Base.bk$3/;
    }
    else{ #Gen or DP
	$line =~ s/(set\(train_pos,\s*)(.*)(\).)/$1'$data$cohorts[$c]$targets[$t].fn'$3/;
	$line =~ s/(set\(train_neg,\s*)(.*)(\).)/$1'$data$cohorts[$c]$targets[($t+1)%2].fn'$3/;
	$line =~ s/(consult\()(.*)(\).)/$1'${data}DP.bk'$3/;
    }

    #if allowing noise or not
    ($noise)?
	($line =~ s/^(\%+)(.*set\(noise)/$2/) :
	($line =~ s/(^.*set\(noise)/\%$1/);

    print OUTPUT $line;
}
